#! /usr/local/bin/perl

#----------------------------------------------------------------------------------------------
#	Author: Ravi Vijaya Satya, BHSAI
#	File: ConvertSNPIndices.pl 
#	Purpose: converts the .tbl file into one in which the indices point to positions 
#	within each chromosome rather than one single concatenated sequence
#-----------------------------------------------------------------------------------------------

use strict;
use warnings;
use Bio::Seq;
use Bio::SeqIO;
use File::Temp qw/ tempfile /;

my %SeqStarts;
my  ($RefCandFileName, $InTblFile, $OutTblFile, $InTblFH, $OutTblFH, $RefCandFile);

if(!@ARGV or $#ARGV < 2){
	die("Usage: perl $0 Reference input_tbl output_tbl");
}
 ($RefCandFileName, $InTblFile, $OutTblFile ) = @ARGV;  

eval{ 
	$RefCandFile = new Bio::SeqIO(-format => 'fasta', -file => $RefCandFileName);
};

if($@){
	die("Problem opening fasta format file $RefCandFileName", $@);
}

my ($NextSeq, $Start, @Tags);
while($NextSeq = $RefCandFile->next_seq()){
	@Tags = split(/\|/, $NextSeq->id());
	if($Tags[1] =~ /start:(\d+)/){
		$SeqStarts{$NextSeq->id()} = $1;
	}
}

open($InTblFH, "<$InTblFile") or die "Could not open $InTblFile for reading";
my ($HdrLine, $StrainCnt, $NewPos);

# read the Hdrline
while(<$InTblFH>){
	$HdrLine = $_;
	@Tags = split;
	$StrainCnt = $#Tags -1;
	last;
}

open($OutTblFH, ">$OutTblFile") or die "Could not open $OutTblFile for writing";

print $OutTblFH $HdrLine;

while(<$InTblFH>){
	@Tags = split;
	$NewPos = $Tags[0] - $SeqStarts{$Tags[$StrainCnt+2]}+1;
	print $OutTblFH join("\t", $NewPos, @Tags[1..(2+$StrainCnt)])."\n";
}

close $InTblFH;
close $OutTblFH;
