#! /usr/local/bin/perl

#----------------------------------------------------------------------------------------------
#	Author: Ravi Vijaya Satya, BHSAI
#	File: MaskTRepeats.pl
#	Purpose: Takes an original fasta file and TRF output.
#   Replaces all TRFs in the original sequence with 'N's while preserving case info
# 	and writes back the input sequence  
#-----------------------------------------------------------------------------------------------

use strict;
use warnings;
use Bio::Seq;
use Bio::SeqIO;

if(!@ARGV or $#ARGV != 2){
	die("usage: perl $0 input_seq_file masked_trf_sequence output_seq_file");
}

my ($OriginalFileName, $TRF_Output_FileName, $OutputFileName) = @ARGV;

my ($OriginalFile, $TRF_Output_File, $OutputFile);


eval{
        $OriginalFile = new Bio::SeqIO(-format => 'fasta', -file => $OriginalFileName);
};
if($@){
        die("Problem opening the final cand file $OriginalFileName", $@);
}

eval{
	$OutputFile = new Bio::SeqIO(-format => 'fasta', -file => ">$OutputFileName");
};
if($@){
	die("problem opening the output file $OutputFileName for writing");
}


my $SeqLength = 0;

my ($NextOriginalSeq, $NextMaskedSeq);
my $TRFOutFH;
my $OutSeq;

open($TRFOutFH, "$TRF_Output_FileName") or die "Could not open $TRF_Output_FileName for reading";

my ($Start, $End, $Mask);

# read the first sequence
while(<$TRFOutFH>){
	if(/^Sequence:/){
		$NextOriginalSeq = $OriginalFile->next_seq();
		$OutSeq = $NextOriginalSeq->seq();
		last;
	}
}

while(<$TRFOutFH>){
	if(/^Sequence:/){
		# write the sequence out
		$NextMaskedSeq = Bio::Seq->new(-id => $NextOriginalSeq->id(), -desc => $NextOriginalSeq->desc(), -seq => $OutSeq);
		$OutputFile->write_seq($NextMaskedSeq);
		
		#read the next sequence
		$NextOriginalSeq = $OriginalFile->next_seq();
		$OutSeq = $NextOriginalSeq->seq();
		next;
	}
	if(/^(\d+)\s+(\d+)\s+/){		# TRF occurrence
		($Start, $End) = ($1, $2);
		$Mask = "N" x ($End - $Start + 1);
		substr($OutSeq, $Start-1, $End-$Start+1, $Mask);
	}
}

# write the last sequence out
$NextMaskedSeq = Bio::Seq->new(-id => $NextOriginalSeq->id(), -desc => $NextOriginalSeq->desc(), -seq => $OutSeq);
$OutputFile->write_seq($NextMaskedSeq);

