#! /usr/local/bin/perl

#--------------------------------------------------------------
#	Author: Ravi Vijaya Satya
#	File: 	PrepareMummerInput.pl
#	Purpose: Takes an input fatsa file which might contain multiple
#			sequences (different chromosomes or just different genomic sequences)
# 			and creates a candidate file, which is essentially the same file as 
#			the input except that the deflines are changed so that all the 
# 			sequences are assumed to be part of single sequence and numbered accordingly.
#---------------------------------------------------------------------------------------

use strict;
use warnings;
use Bio::Seq;
use Bio::SeqIO;

if (!@ARGV or $#ARGV < 2){
	die("Usage: perl $0 input_fasta_file_name genome_prefix output_cand_file_name");
}

my ($FastaFileName, $GenomePrefix, $CandFileName) = @ARGV;

my $FastaFile;
eval{
	$FastaFile = new Bio::SeqIO(-format => 'fasta', -file => $FastaFileName);
};

if($@){
	die("Problem opening fasta format file $FastaFileName", $@);
}

my $CandFile;

eval{
	$CandFile = new Bio::SeqIO(-format => 'fasta', -file => ">$CandFileName");
};

if($@){
	die("Problem creating the cand file $CandFileName", $@);
}

my $NextBegin = 1;	
my $NextEnd = 0; 
my $Length = 0;
my $CandDefLine;
my $SeqCtr=1;

# consider later if you can give a better description than "seq"

while (my $NextSequence = $FastaFile->next_seq()){
	$Length = $NextSequence->length();
	$NextEnd = $NextBegin+$Length-1;
	$CandDefLine="|start:$NextBegin|end:$NextEnd|length:$Length|";
	# In the following, execute alternate statements depending on whether to treat each sequence separately or as parts of one single sequence
	$NextBegin = $NextEnd+1;  	# treating all the input sequences as part one single, huge sequence
	#$NextBegin = 1;					# treating the input sequences as separate, un-connected sequences. 
	my $NextCand = Bio::Seq->new(-id => $GenomePrefix."seq".$SeqCtr.$CandDefLine, -seq => $NextSequence->seq());
	$CandFile->write_seq($NextCand);
	$SeqCtr++;
}
